@@ -79,18 +79,22 @@ netleague <- function(x, y,
     lower.fixed.x <- x$lower.direct.fixed
     upper.fixed.x <- x$upper.direct.fixed
     ##
-    TE.random.x    <- x$TE.direct.random
-    lower.random.x <- x$lower.direct.random
-    upper.random.x <- x$upper.direct.random
+    if (comb.random) {
+      TE.random.x    <- x$TE.direct.random
+      lower.random.x <- x$lower.direct.random
+      upper.random.x <- x$upper.direct.random
+    }
   }
   else {
     TE.fixed.x    <- x$TE.fixed
     lower.fixed.x <- x$lower.fixed
     upper.fixed.x <- x$upper.fixed
     ##
-    TE.random.x    <- x$TE.random
-    lower.random.x <- x$lower.random
-    upper.random.x <- x$upper.random
+    if (comb.random) {
+      TE.random.x    <- x$TE.random
+      lower.random.x <- x$lower.random
+      upper.random.x <- x$upper.random
+    }
   }
   ##
   if (backtransf & is.relative.effect(x$sm)) {
@@ -98,9 +102,11 @@ netleague <- function(x, y,
     lower.fixed.x <- exp(lower.fixed.x)
     upper.fixed.x <- exp(upper.fixed.x)
     ##
-    TE.random.x    <- exp(TE.random.x)
-    lower.random.x <- exp(lower.random.x)
-    upper.random.x <- exp(upper.random.x)
+    if (comb.random) {
+      TE.random.x    <- exp(TE.random.x)
+      lower.random.x <- exp(lower.random.x)
+      upper.random.x <- exp(upper.random.x)
+    }
   }
   ##
   if (!missing(y)) {
@@ -109,18 +115,22 @@ netleague <- function(x, y,
       lower.fixed.y <- y$lower.direct.fixed
       upper.fixed.y <- y$upper.direct.fixed
       ##
-      TE.random.y    <- y$TE.direct.random
-      lower.random.y <- y$lower.direct.random
-      upper.random.y <- y$upper.direct.random
+      if (comb.random) {
+        TE.random.y    <- y$TE.direct.random
+        lower.random.y <- y$lower.direct.random
+        upper.random.y <- y$upper.direct.random
+      }
     }
     else {
       TE.fixed.y    <- y$TE.fixed
       lower.fixed.y <- y$lower.fixed
       upper.fixed.y <- y$upper.fixed
       ##
-      TE.random.y    <- y$TE.random
-      lower.random.y <- y$lower.random
-      upper.random.y <- y$upper.random
+      if (comb.random) {
+        TE.random.y    <- y$TE.random
+        lower.random.y <- y$lower.random
+        upper.random.y <- y$upper.random
+      }
     }
     ##
     if (backtransf & is.relative.effect(y$sm)) {
@@ -128,9 +138,11 @@ netleague <- function(x, y,
       lower.fixed.y <- exp(lower.fixed.y)
       upper.fixed.y <- exp(upper.fixed.y)
       ##
-      TE.random.y    <- exp(TE.random.y)
-      lower.random.y <- exp(lower.random.y)
-      upper.random.y <- exp(upper.random.y)
+      if (comb.random) {
+        TE.random.y    <- exp(TE.random.y)
+        lower.random.y <- exp(lower.random.y)
+        upper.random.y <- exp(upper.random.y)
+      }
     }
     ##
     if (x.is.y) {
@@ -138,9 +150,11 @@ netleague <- function(x, y,
       lower.fixed.y <- t(lower.fixed.y)
       upper.fixed.y <- t(upper.fixed.y)
       ##
-      TE.random.y    <- t(TE.random.y)
-      lower.random.y <- t(lower.random.y)
-      upper.random.y <- t(upper.random.y)
+      if (comb.random) {
+        TE.random.y    <- t(TE.random.y)
+        lower.random.y <- t(lower.random.y)
+        upper.random.y <- t(upper.random.y)
+      }
     }
   }
   else {
@@ -149,18 +163,22 @@ netleague <- function(x, y,
       lower.fixed.y <- exp(x$lower.direct.fixed)
       upper.fixed.y <- exp(x$upper.direct.fixed)
       ##
-      TE.random.y    <- exp(x$TE.direct.random)
-      lower.random.y <- exp(x$lower.direct.random)
-      upper.random.y <- exp(x$upper.direct.random)
+      if (comb.random) {
+        TE.random.y    <- exp(x$TE.direct.random)
+        lower.random.y <- exp(x$lower.direct.random)
+        upper.random.y <- exp(x$upper.direct.random)
+      }
     }
     else {
       TE.fixed.y    <- x$TE.direct.fixed
       lower.fixed.y <- x$lower.direct.fixed
       upper.fixed.y <- x$upper.direct.fixed
       ##
-      TE.random.y    <- x$TE.direct.random
-      lower.random.y <- x$lower.direct.random
-      upper.random.y <- x$upper.direct.random
+      if (comb.random) {
+        TE.random.y    <- x$TE.direct.random
+        lower.random.y <- x$lower.direct.random
+        upper.random.y <- x$upper.direct.random
+      }
     }
   }
   ##
@@ -170,17 +188,21 @@ netleague <- function(x, y,
   lower.fixed.x <- t(lower.fixed.x)
   upper.fixed.x <- t(upper.fixed.x)
   ##
-  TE.random.x <- t(TE.random.x)
-  lower.random.x <- t(lower.random.x)
-  upper.random.x <- t(upper.random.x)
+  if (comb.random) {
+    TE.random.x <- t(TE.random.x)
+    lower.random.x <- t(lower.random.x)
+    upper.random.x <- t(upper.random.x)
+  }
   ##
   TE.fixed.y <- t(TE.fixed.y)
   lower.fixed.y <- t(lower.fixed.y)
   upper.fixed.y <- t(upper.fixed.y)
   ##
-  TE.random.y <- t(TE.random.y)
-  lower.random.y <- t(lower.random.y)
-  upper.random.y <- t(upper.random.y)
+  if (comb.random) {
+    TE.random.y <- t(TE.random.y)
+    lower.random.y <- t(lower.random.y)
+    upper.random.y <- t(upper.random.y)
+  }
   
   
   ##
@@ -194,13 +216,15 @@ netleague <- function(x, y,
   ##
   if (ci) {
     nl.NA <- is.na(TE.fixed.x)
-    nl.f <- paste(formatN(TE.fixed.x, text.NA = text.NA, big.mark = big.mark),
+    nl.f <- paste(formatN(TE.fixed.x, digits = digits,
+                          text.NA = text.NA, big.mark = big.mark),
                   formatCI(lower.fixed.x, upper.fixed.x, lab.NA = text.NA,
                            big.mark = big.mark))
     nl.f[nl.NA] <- text.NA
   }
   else
-    nl.f <- formatN(TE.fixed.x, text.NA = text.NA, big.mark = big.mark)
+    nl.f <- formatN(TE.fixed.x, digits = digits,
+                    text.NA = text.NA, big.mark = big.mark)
   ##
   nl.f <- matrix(nl.f, nrow = nrow(TE.fixed.x), ncol = ncol(TE.fixed.x))
   diag(nl.f) <- rownames(TE.fixed.x)
@@ -211,13 +235,15 @@ netleague <- function(x, y,
   ##
   if (ci) {
     nl.NA <- is.na(TE.fixed.y)
-    nl.f.y <- paste(formatN(TE.fixed.y, text.NA = text.NA, big.mark = big.mark),
+    nl.f.y <- paste(formatN(TE.fixed.y,
+                            digits = digits, text.NA = text.NA, big.mark = big.mark),
                     formatCI(lower.fixed.y, upper.fixed.y, lab.NA = text.NA,
                              big.mark = big.mark))
     nl.f.y[nl.NA] <- text.NA
   }
   else
-    nl.f.y <- formatN(TE.fixed.y, text.NA = text.NA, big.mark = big.mark)
+    nl.f.y <- formatN(TE.fixed.y, digits = digits,
+                      text.NA = text.NA, big.mark = big.mark)
   ##
   nl.f.y <- matrix(nl.f.y, nrow = nrow(TE.fixed.y), ncol = ncol(TE.fixed.y))
   ##
@@ -231,45 +257,51 @@ netleague <- function(x, y,
   ## (4) Print league table for random effects model
   ##
   ##
-  TE.random.x    <- round(   TE.random.x[seq.r, seq.r], digits)
-  lower.random.x <- round(lower.random.x[seq.r, seq.r], digits)
-  upper.random.x <- round(upper.random.x[seq.r, seq.r], digits)
-  ##
-  if (ci) {
-    nl.NA <- is.na(TE.random.x)
-    nl.r <- paste(formatN(TE.random.x, text.NA = text.NA, big.mark = big.mark),
-                  formatCI(lower.random.x, upper.random.x, lab.NA = text.NA,
-                           big.mark = big.mark))
-    nl.r[nl.NA] <- text.NA
+  if (comb.random) {
+    TE.random.x    <- round(   TE.random.x[seq.r, seq.r], digits)
+    lower.random.x <- round(lower.random.x[seq.r, seq.r], digits)
+    upper.random.x <- round(upper.random.x[seq.r, seq.r], digits)
+    ##
+    if (ci) {
+      nl.NA <- is.na(TE.random.x)
+      nl.r <- paste(formatN(TE.random.x, digits = digits,
+                            text.NA = text.NA, big.mark = big.mark),
+                    formatCI(lower.random.x, upper.random.x, lab.NA = text.NA,
+                             big.mark = big.mark))
+      nl.r[nl.NA] <- text.NA
+    }
+    else
+      nl.r <- formatN(TE.random.x, digits = digits,
+                      text.NA = text.NA, big.mark = big.mark)
+    ##
+    nl.r <- matrix(nl.r, nrow = nrow(TE.random.x), ncol = ncol(TE.random.x))
+    diag(nl.r) <- rownames(TE.random.x)
+    ##
+    TE.random.y    <- round(   TE.random.y[seq.r, seq.r], digits)
+    lower.random.y <- round(lower.random.y[seq.r, seq.r], digits)
+    upper.random.y <- round(upper.random.y[seq.r, seq.r], digits)
+    ##
+    if (ci) {
+      nl.NA <- is.na(TE.random.y)
+      nl.r.y <- paste(formatN(TE.random.y, digits = digits,
+                              text.NA = text.NA),
+                      formatCI(lower.random.y, upper.random.y, lab.NA = text.NA))
+      nl.r.y[nl.NA] <- text.NA
+    }
+    else
+      nl.r.y <- formatN(TE.random.y, digits = digits,
+                        text.NA = text.NA, big.mark = big.mark)
+    ##
+    nl.r.y <- matrix(nl.r.y, nrow = nrow(TE.random.y), ncol = ncol(TE.random.y))
+    ##
+    nl.r[upper.tri(nl.r)] <- t(nl.r.y)[upper.tri(nl.f)]
+    ##
+    nl.r <- as.data.frame(nl.r, stringsAsFactors = FALSE)
   }
-  else
-    nl.r <- formatN(TE.random.x, text.NA = text.NA, big.mark = big.mark)
-  ##
-  nl.r <- matrix(nl.r, nrow = nrow(TE.random.x), ncol = ncol(TE.random.x))
-  diag(nl.r) <- rownames(TE.random.x)
-  ##
-  TE.random.y    <- round(   TE.random.y[seq.r, seq.r], digits)
-  lower.random.y <- round(lower.random.y[seq.r, seq.r], digits)
-  upper.random.y <- round(upper.random.y[seq.r, seq.r], digits)
-  ##
-  if (ci) {
-    nl.NA <- is.na(TE.random.y)
-    nl.r.y <- paste(formatN(TE.random.y, text.NA = text.NA),
-                    formatCI(lower.random.y, upper.random.y, lab.NA = text.NA))
-    nl.r.y[nl.NA] <- text.NA
-  }
-  else
-    nl.r.y <- formatN(TE.random.y, text.NA = text.NA, big.mark = big.mark)
-  ##
-  nl.r.y <- matrix(nl.r.y, nrow = nrow(TE.random.y), ncol = ncol(TE.random.y))
-  ##
-  nl.r[upper.tri(nl.r)] <- t(nl.r.y)[upper.tri(nl.f)]
-  ##
-  nl.r <- as.data.frame(nl.r, stringsAsFactors = FALSE)
   
   
   res <- list(fixed = nl.f,
-              random = nl.r,
+              random = if (comb.random) nl.r else NA,
               comb.fixed = comb.fixed,
               comb.random = comb.random,
               seq = seq, ci = ci, backtransf = backtransf,
